==> ejc-signaturemanage-impl-3.0.1-20221119.041435-217-sources.jar: com/ejianc/business/signaturemanage/bean/SignMgrEntity.java <==
package com.ejianc.business.signaturemanage.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 签章管理
 *
 * @author generator
 */
@TableName("ejc_signmgr")
public class SignMgrEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField("del_flag")
	private Integer delFlag; // 0-未删除，1-已删除
	@TableField(value = "bill_id")
	private java.lang.Long billId; // 业务id
	@TableField(value = "bill_type")
	private java.lang.String billType; // 来源业务单据类型
	@TableField(value = "bill_code")
	private String billCode; // 单据编号
	@TableField(value = "bill_name")
	private String billName; // 单据名称
	@TableField(value = "contract_name")
	private String contractName; // 合同名称
	@TableField(value = "contract_tax_mny")
	private BigDecimal contractTaxMny; // 合同金额(含税)
	@TableField(value = "org_id")
	private Long orgId; // 组织id
	@TableField(value = "org_code")
	private String orgCode; // 组织编号
	@TableField(value = "org_name")
	private String orgName; // 组织名称
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_code")
	private String projectCode; // 项目编号
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "bill_ref_code")
	private java.lang.String billRefCode; // refcode
	@TableField(value = "source_bill_id")
	private java.lang.Long sourceBillId; // 业务id（第三方系统返回的）
	@TableField(value = "source_doc_id")
	private java.lang.Long sourceDocId; // 业务文档id（第三方系统返回的）
	@TableField(value = "bill_doc_id")
	private java.lang.Long billDocId; // 业务文件id
	@TableField(value = "bill_document_name")
	private java.lang.String billDocumentName; // 业务文件名称
	@TableField(value = "bill_document_type")
	private java.lang.String billDocumentType; // 业务文件类型
	@TableField(value = "sign_requirements")
	private java.lang.String signRequirements; // 签署要求

	@TableField(value = "creator_name")
	private java.lang.String creatorName; // 创建人名称
	@TableField(value = "creator_contact")
	private java.lang.String creatorContact; // 创建人联系方式
	@TableField(value = "tenant_name")
	private java.lang.String tenantName; // 发起方名称
	@TableField(value = "subject")
	private String subject; // 主题 (签章主题：PM系统：单据名称-单据编号)


	@TableField(exist = false)
	@SubEntity(serviceName = "signMgrSignatoryService")
	private List<SignMgrSignatoryEntity> signMgrSignatoryEntities = new ArrayList<>(); // 签章管理-签署方子表

	public Integer getDelFlag() {
		return delFlag;
	}

	public void setDelFlag(Integer delFlag) {
		this.delFlag = delFlag;
	}

	/**
	 * 业务id
	 */
	public java.lang.Long getBillId() {
		return billId;
	}

	/**
	 * 业务id
	 */
	public void setBillId(java.lang.Long billId) {
		this.billId = billId;
	}

	/**
	 * 来源业务单据类型
	 */
	public java.lang.String getBillType() {
		return billType;
	}

	/**
	 * 来源业务单据类型
	 */
	public void setBillType(java.lang.String billType) {
		this.billType = billType;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getContractName() {
		return contractName;
	}

	public void setContractName(String contractName) {
		this.contractName = contractName;
	}

	public BigDecimal getContractTaxMny() {
		return contractTaxMny;
	}

	public void setContractTaxMny(BigDecimal contractTaxMny) {
		this.contractTaxMny = contractTaxMny;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgCode() {
		return orgCode;
	}

	public void setOrgCode(String orgCode) {
		this.orgCode = orgCode;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getBillRefCode() {
		return billRefCode;
	}

	public void setBillRefCode(String billRefCode) {
		this.billRefCode = billRefCode;
	}

	/**
	 * 业务id（第三方系统返回的）
	 */
	public java.lang.Long getSourceBillId() {
		return sourceBillId;
	}

	/**
	 * 业务id（第三方系统返回的）
	 */
	public void setSourceBillId(java.lang.Long sourceBillId) {
		this.sourceBillId = sourceBillId;
	}

	/**
	 * 业务文档id（第三方系统返回的）
	 */
	public java.lang.Long getSourceDocId() {
		return sourceDocId;
	}

	/**
	 * 业务文档id（第三方系统返回的）
	 */
	public void setSourceDocId(java.lang.Long sourceDocId) {
		this.sourceDocId = sourceDocId;
	}

	/**
	 * 业务文件id
	 */
	public java.lang.Long getBillDocId() {
		return billDocId;
	}

	/**
	 * 业务文件id
	 */
	public void setBillDocId(java.lang.Long billDocId) {
		this.billDocId = billDocId;
	}

	/**
	 * 业务文件名称
	 */
	public java.lang.String getBillDocumentName() {
		return billDocumentName;
	}

	/**
	 * 业务文件名称
	 */
	public void setBillDocumentName(java.lang.String billDocumentName) {
		this.billDocumentName = billDocumentName;
	}

	/**
	 * 业务文件类型
	 */
	public java.lang.String getBillDocumentType() {
		return billDocumentType;
	}

	/**
	 * 业务文件类型
	 */
	public void setBillDocumentType(java.lang.String billDocumentType) {
		this.billDocumentType = billDocumentType;
	}

	/**
	 * 签署要求
	 */
	public java.lang.String getSignRequirements() {
		return signRequirements;
	}

	/**
	 * 签署要求
	 */
	public void setSignRequirements(java.lang.String signRequirements) {
		this.signRequirements = signRequirements;
	}

	/**
	 * 创建人名称
	 */
	public String getCreatorName() {
		return creatorName;
	}

	/**
	 * 创建人名称
	 */
	public void setCreatorName(String creatorName) {
		this.creatorName = creatorName;
	}

	/**
	 * 创建人联系方式
	 */
	public String getCreatorContact() {
		return creatorContact;
	}

	/**
	 * 创建人联系方式
	 */
	public void setCreatorContact(String creatorContact) {
		this.creatorContact = creatorContact;
	}

	/**
	 * 发起方名称
	 */
	public String getTenantName() {
		return tenantName;
	}

	/**
	 * 发起方名称
	 */
	public void setTenantName(String tenantName) {
		this.tenantName = tenantName;
	}

	/**
	 * 签章管理-签署方子表
	 */
	public List<SignMgrSignatoryEntity> getSignMgrSignatoryEntities() {
		return signMgrSignatoryEntities;
	}

	/**
	 * 签章管理-签署方子表
	 */
	public void setSignMgrSignatoryEntities(List<SignMgrSignatoryEntity> signMgrSignatoryEntities) {
		this.signMgrSignatoryEntities = signMgrSignatoryEntities;
	}

	public String getSubject() {
		return subject;
	}

	public void setSubject(String subject) {
		this.subject = subject;
	}
}

==> ejc-signaturemanage-impl-3.0.1-20241218.094052-331-sources.jar: com/ejianc/business/signaturemanage/bean/SignMgrEntity.java <==
package com.ejianc.business.signaturemanage.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 签章管理
 *
 * @author generator
 */
@TableName("ejc_signmgr")
public class SignMgrEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField("del_flag")
	private Integer delFlag; // 0-未删除，1-已删除
	@TableField(value = "bill_id")
	private java.lang.Long billId; // 业务id
	@TableField(value = "bill_type")
	private java.lang.String billType; // 来源业务单据类型
	@TableField(value = "bill_code")
	private String billCode; // 单据编号
	@TableField(value = "bill_name")
	private String billName; // 单据名称
	@TableField(value = "contract_name")
	private String contractName; // 合同名称
	@TableField(value = "contract_tax_mny")
	private BigDecimal contractTaxMny; // 合同金额(含税)
	@TableField(value = "org_id")
	private Long orgId; // 组织id
	@TableField(value = "org_code")
	private String orgCode; // 组织编号
	@TableField(value = "org_name")
	private String orgName; // 组织名称
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_code")
	private String projectCode; // 项目编号
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "bill_ref_code")
	private java.lang.String billRefCode; // refcode
	@TableField(value = "source_bill_id")
	private java.lang.Long sourceBillId; // 业务id（第三方系统返回的）
	@TableField(value = "source_doc_id")
	private java.lang.Long sourceDocId; // 业务文档id（第三方系统返回的）
	@TableField(value = "bill_doc_id")
	private java.lang.Long billDocId; // 业务文件id
	@TableField(value = "bill_document_name")
	private java.lang.String billDocumentName; // 业务文件名称
	@TableField(value = "bill_document_type")
	private java.lang.String billDocumentType; // 业务文件类型
	@TableField(value = "sign_requirements")
	private java.lang.String signRequirements; // 签署要求

	@TableField(value = "creator_name")
	private java.lang.String creatorName; // 创建人名称
	@TableField(value = "creator_contact")
	private java.lang.String creatorContact; // 创建人联系方式
	@TableField(value = "tenant_name")
	private java.lang.String tenantName; // 发起方名称
	@TableField(value = "subject")
	private String subject; // 主题 (签章主题：PM系统：单据名称-单据编号)

	@TableField(value = "sign_status")
	private Integer signStatus; //签章流程状态：1-待签章,2-待乙方签章,3-待甲方签章,4-已签章（已完成）,5-已退回（已拒签）,6-已撤回,7-已过期,8-其他

	@TableField(exist = false)
	@SubEntity(serviceName = "signMgrSignatoryService")
	private List<SignMgrSignatoryEntity> signMgrSignatoryEntities = new ArrayList<>(); // 签章管理-签署方子表

	/**
	 * 撤回时间
	 */
	@TableField(value = "recall_time")
	private Date recallTime;
	/**
	 * 撤回用户Id
	 */
	@TableField(value = "recall_user_id")
	private Long recallUserId;
	/**
	 * 撤回用户名称
	 */
	@TableField(value = "recall_user_name")
	private String recallUserName;
	/**
	 * 撤回原因
	 */
	@TableField(value = "recall_reason")
	private String recallReason;

	/**
	 * 流程结束时间
	 */
	@TableField(value = "finish_time")
	private Date finishTime;

	public Date getFinishTime() {
		return finishTime;
	}

	public void setFinishTime(Date finishTime) {
		this.finishTime = finishTime;
	}

	public Date getRecallTime() {
		return recallTime;
	}

	public void setRecallTime(Date recallTime) {
		this.recallTime = recallTime;
	}

	public Long getRecallUserId() {
		return recallUserId;
	}

	public void setRecallUserId(Long recallUserId) {
		this.recallUserId = recallUserId;
	}

	public String getRecallUserName() {
		return recallUserName;
	}

	public void setRecallUserName(String recallUserName) {
		this.recallUserName = recallUserName;
	}

	public String getRecallReason() {
		return recallReason;
	}

	public void setRecallReason(String recallReason) {
		this.recallReason = recallReason;
	}

	public Integer getDelFlag() {
		return delFlag;
	}

	public void setDelFlag(Integer delFlag) {
		this.delFlag = delFlag;
	}

	public Integer getSignStatus() {
		return signStatus;
	}

	public void setSignStatus(Integer signStatus) {
		this.signStatus = signStatus;
	}

	/**
	 * 业务id
	 */
	public java.lang.Long getBillId() {
		return billId;
	}

	/**
	 * 业务id
	 */
	public void setBillId(java.lang.Long billId) {
		this.billId = billId;
	}

	/**
	 * 来源业务单据类型
	 */
	public java.lang.String getBillType() {
		return billType;
	}

	/**
	 * 来源业务单据类型
	 */
	public void setBillType(java.lang.String billType) {
		this.billType = billType;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getContractName() {
		return contractName;
	}

	public void setContractName(String contractName) {
		this.contractName = contractName;
	}

	public BigDecimal getContractTaxMny() {
		return contractTaxMny;
	}

	public void setContractTaxMny(BigDecimal contractTaxMny) {
		this.contractTaxMny = contractTaxMny;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgCode() {
		return orgCode;
	}

	public void setOrgCode(String orgCode) {
		this.orgCode = orgCode;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getBillRefCode() {
		return billRefCode;
	}

	public void setBillRefCode(String billRefCode) {
		this.billRefCode = billRefCode;
	}

	/**
	 * 业务id（第三方系统返回的）
	 */
	public java.lang.Long getSourceBillId() {
		return sourceBillId;
	}

	/**
	 * 业务id（第三方系统返回的）
	 */
	public void setSourceBillId(java.lang.Long sourceBillId) {
		this.sourceBillId = sourceBillId;
	}

	/**
	 * 业务文档id（第三方系统返回的）
	 */
	public java.lang.Long getSourceDocId() {
		return sourceDocId;
	}

	/**
	 * 业务文档id（第三方系统返回的）
	 */
	public void setSourceDocId(java.lang.Long sourceDocId) {
		this.sourceDocId = sourceDocId;
	}

	/**
	 * 业务文件id
	 */
	public java.lang.Long getBillDocId() {
		return billDocId;
	}

	/**
	 * 业务文件id
	 */
	public void setBillDocId(java.lang.Long billDocId) {
		this.billDocId = billDocId;
	}

	/**
	 * 业务文件名称
	 */
	public java.lang.String getBillDocumentName() {
		return billDocumentName;
	}

	/**
	 * 业务文件名称
	 */
	public void setBillDocumentName(java.lang.String billDocumentName) {
		this.billDocumentName = billDocumentName;
	}

	/**
	 * 业务文件类型
	 */
	public java.lang.String getBillDocumentType() {
		return billDocumentType;
	}

	/**
	 * 业务文件类型
	 */
	public void setBillDocumentType(java.lang.String billDocumentType) {
		this.billDocumentType = billDocumentType;
	}

	/**
	 * 签署要求
	 */
	public java.lang.String getSignRequirements() {
		return signRequirements;
	}

	/**
	 * 签署要求
	 */
	public void setSignRequirements(java.lang.String signRequirements) {
		this.signRequirements = signRequirements;
	}

	/**
	 * 创建人名称
	 */
	public String getCreatorName() {
		return creatorName;
	}

	/**
	 * 创建人名称
	 */
	public void setCreatorName(String creatorName) {
		this.creatorName = creatorName;
	}

	/**
	 * 创建人联系方式
	 */
	public String getCreatorContact() {
		return creatorContact;
	}

	/**
	 * 创建人联系方式
	 */
	public void setCreatorContact(String creatorContact) {
		this.creatorContact = creatorContact;
	}

	/**
	 * 发起方名称
	 */
	public String getTenantName() {
		return tenantName;
	}

	/**
	 * 发起方名称
	 */
	public void setTenantName(String tenantName) {
		this.tenantName = tenantName;
	}

	/**
	 * 签章管理-签署方子表
	 */
	public List<SignMgrSignatoryEntity> getSignMgrSignatoryEntities() {
		return signMgrSignatoryEntities;
	}

	/**
	 * 签章管理-签署方子表
	 */
	public void setSignMgrSignatoryEntities(List<SignMgrSignatoryEntity> signMgrSignatoryEntities) {
		this.signMgrSignatoryEntities = signMgrSignatoryEntities;
	}

	public String getSubject() {
		return subject;
	}

	public void setSubject(String subject) {
		this.subject = subject;
	}
}
